About MetPyRad
==============

Get support
-----------

If you need support, please check the **MetPyRad** `documentation <https://github.com/lmri-met/metpyrad/blob/main/README.md>`_.
If you need further support, please `send us an e-mail <mailto:xandra.campo@ciemat.es>`_.

Contribute
----------

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.
Please check the **MetPyRad** `issues page <https://github.com/lmri-met/metpyrad/issues/>`_ if you want to contribute.

License
-------

**MetPyRad** is distributed under the `GNU GPLv3 License <https://choosealicense.com/licenses/gpl-3.0/>`_.

Distribution
------------

**MetPyRad** is distributed via `PyPI <https://pypi.org/project/metpyrad/>`_.

Contributors
------------

**MetPyRad** is developed and maintained by `Xandra Campo <https://github.com/xandratxan/>`_,
with the support of Nuria Navarro and Virginia Peyres.
It is one of the projects of the `Ionizing Radiation Metrology Laboratory (LMRI) <https://github.com/lmri-met/>`_,
which is the Spanish National Metrology Institute for ionizing radiation.

Change log
----------

0.0.1
^^^^^

- Initial release.
